iframe html[data-v-0f01bba5]{cursor:pointer}#console{height:auto;border:1px solid #dfe6ec}#console p{margin-top:5px;margin-bottom:5px}#console p button{margin-right:5px}#console p a{color:#48576a;font-weight:400}#console label .el-button{width:100%}#follows #follow-items,#follows #follow-requests{border:1px solid #dfe6ec;overflow-y:scroll;max-height:400px}#follows #follow-items .el-loading-mask,#follows #follow-requests .el-loading-mask{height:10000px}#follows #follow-items .follow-item{border-bottom:1px solid #dfe6ec}#follows #follow-items .follow-item .key{width:10%}#follows #follow-items .follow-item .value{width:90%}#follows #follow-requests .follow-request{position:relative;height:40px;line-height:40px;padding-left:5px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;cursor:pointer;border-bottom:1px solid #dfe6ec}#follows #follow-web iframe{border:1px solid #dfe6ec;min-height:500px}#follows #follow-html{max-height:500px;overflow:scroll;border:1px solid #dfe6ec;padding:15px}.el-tabs__item.is-active{color:#28ccaa!important}.el-tabs__active-bar{background-color:#28ccaa!important}.code-editor{font-size:16px}.code-editor .CodeMirror{max-height:200px}.code-editor .CodeMirror-line{height:25px;line-height:25px!important}#project-configure #info .el-form,#project-configure #items .el-form,#project-configure #spiders .el-form{padding:20px 30px}#project-configure #info .el-form .el-form-item{margin-bottom:0}.inline{display:inline-block}.inline.short{max-width:100px!important}.inline.medium{max-width:200px!important}.inline.long{max-width:400px!important}#save{position:fixed;width:40px;height:40px;border-radius:50%;right:20px;bottom:20px;z-index:1000;font-size:12px;padding-left:15px}
/*# sourceMappingURL=chunk-582dc9b0.94c01b9b.css.map */