#task-status .el-form .el-form-item[data-v-0ccb3569]{margin-bottom:5px}#task-status .description[data-v-0ccb3569]{font-size:14px;color:#606266}#task-status .pie[data-v-0ccb3569]{position:relative;top:-20px}h1.number[data-v-0ccb3569]{font-weight:100;margin:10px 0;margin-top:0}.text[data-v-0ccb3569]{font-size:14px;color:#535351}
/*# sourceMappingURL=chunk-2ab4c347.a74091e8.css.map */