#project-index .dialog .el-dialog__body{padding-bottom:0;padding-left:40px;padding-right:40px}#project-index .upload,#project-index .upload .el-upload,#project-index .upload .el-upload .el-upload-dragger{width:100%}
/*# sourceMappingURL=chunk-736ea204.31923c28.css.map */