/*
  WARNING: DO NOT MODIFY OR DELETE
  This file is auto-generated by Quasar CLI
  It's recommended to NOT .gitignore it
  You don't have to use TypeScript in your project, don't worry
*/
import "quasar/dist/types/feature-flag.d.ts";

declare module "quasar/dist/types/feature-flag.d.ts" {
  interface QuasarFeatureFlags {
    store: true;
  }
}
